==> jmb.core-0.3.tar.gz: jmb.core-0.3/jmb/core/static/jmb/js/search_form.js <==
var $ = django.jQuery;

django.jQuery(document).ready(function($) {
    //hide the all of the element with class msg_body
    $("#search_form_body").hide();
    //toggle the componenet with class msg_body
    $("#search_form_head").click(function()
        {
            $(this).next("#search_form_body").slideToggle(500);
        }
    );

    $("#search_form").bind("keypress", function(e) {
        if (e.keyCode == 13) {
            go_search();
            return false;
         }
    });

    $('#bsearch').click(function() {
            go_search();
    });

    /* JAVASCRIPT PER FARE IN MODO CHE I FLITRI SIANO INIZIALMENTE CHIUSI E SI APRONO CON LO SLIDE */
    $('#show-filters').prependTo('div.actions');

    $('#changelist-filter').hide('fast');
    $('#show-filters').show();
    $('#changelist').removeClass('filtered');

    $('#changelist-filter h2'). css( 'cursor', 'pointer' );

    $('#changelist-filter h2').click( function() {
        $('#changelist-filter').hide('fast');
        $('#show-filters').show();
        $('#changelist').removeClass('filtered');
    });

    $('#show-filters').click(function() {
        $('#changelist-filter').show('fast');
        $('#changelist').addClass('filtered');
        $('#show-filters').hide();
    });
});

function go_search_too_simle() {
    // we don't want empty values to pollute GET URL
    var f = $('#search_form').find('input, select').not('[value=""]')
    window.location = "?" + f.serialize();
}

var get_values = function(obj){
	var output = ($(obj).val()|| []).join(',');
	return output
};

function go_search() {
    /* questa versione crea un URL per GET non canonica ma facile 
       da usare per i widget con selezioen multipla. Es.:
       status__in=1,2
    */
    var var_name = '';
    var filter_str = '';
	// we don't want empty values to pollute GET URL
	var f = $('#search_form').find('input, select:not([multiple])').not('[value=""]')
	$('#search_form').find('select:[multiple]').not('[value=""]').each(function(index, value){
        // TODO: meditare se __in debbaessere aggiunto dal javascript
        // o se sta nel nome del campo
	    // output = $(value).attr('name') + "__in=" + get_values(value);
	    output = $(value).attr('name') + "=" + get_values(value);
	    filter_str =  filter_str + "&" + output;
	});
	var new_location = "?" + f.serialize() + filter_str; 
    window.location = new_location;
}

==> jmb.core-0.3.1.tar.gz: jmb.core-0.3.1/jmb/core/static/jmb/js/search_form.js <==
var $ = django.jQuery;

django.jQuery(document).ready(function($) {
    //hide the all of the element with class msg_body
    $("#search_form_body").hide();
    //toggle the componenet with class msg_body
    $("#search_form_head").click(function()
        {
            $(this).next("#search_form_body").slideToggle(500);
        }
    );

    $("#search_form").bind("keypress", function(e) {
        if (e.keyCode == 13) {
            go_search();
            return false;
         }
    });

    $('#bsearch').click(function() {
            go_search();
    });

    /* JAVASCRIPT PER FARE IN MODO CHE I FLITRI SIANO INIZIALMENTE CHIUSI E SI APRONO CON LO SLIDE */
    $('#show-filters').prependTo('div.actions');

    $('#changelist-filter').hide('fast');
    $('#show-filters').show();
    $('#changelist').removeClass('filtered');

    $('#changelist-filter h2'). css( 'cursor', 'pointer' );

    $('#changelist-filter h2').click( function() {
        $('#changelist-filter').hide('fast');
        $('#show-filters').show();
        $('#changelist').removeClass('filtered');
    });

    $('#show-filters').click(function() {
        $('#changelist-filter').show('fast');
        $('#changelist').addClass('filtered');
        $('#show-filters').hide();
    });
});

function go_search() {
    // we don't want empty values to pollute GET URL
    var f = $('#search_form').find('input, select').not('[value=""]')
    window.location = "?" + f.serialize();
}

var get_values = function(obj){
	var output = ($(obj).val()|| []).join(',');
	return output
};

function go_search_() {
    /* questa versione crea un URL per GET non canonica ma facile 
       da usare per i widget con selezioen multipla. Es.:
       status__in=1,2
    */
    var var_name = '';
    var filter_str = '';
	// we don't want empty values to pollute GET URL
	var f = $('#search_form').find('input, select:not([multiple])').not('[value=""]')
	$('#search_form').find('select:[multiple]').not('[value=""]').each(function(index, value){
        // TODO: meditare se __in debbaessere aggiunto dal javascript
        // o se sta nel nome del campo
	    // output = $(value).attr('name') + "__in=" + get_values(value);
	    output = $(value).attr('name') + "=" + get_values(value);
	    filter_str =  filter_str + "&" + output;
	});
	var new_location = "?" + f.serialize() + filter_str; 
    window.location = new_location;
}
